==> nodejs_translate-1.0.0.tar.gz: nodejs_translate/src/Commands/MultipleTranslateCommand.php <==
<?php

namespace Drupal\nodejs_translate\Commands;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\nodejs_translate\NodejsTranslator;
use Drush\Commands\DrushCommands;

/**
 * A drush command file.
 *
 * @package Drupal\nodejs_translate\Commands
 */
class MultipleTranslateCommand extends DrushCommands {

  /**
   * Drupal\Core\Entity\EntityTypeManagerInterface definition.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Translator for text service.
   *
   * @var \Drupal\nodejs_translate\NodejsTranslator
   */
  protected $translator;

  /**
   * Constructs Node.js Multiple Translate command.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\nodejs_translate\NodejsTranslator $translator
   *   The text translator.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, NodejsTranslator $translator) {
    $this->entityTypeManager = $entity_type_manager;
    $this->translator = $translator;
  }

  /**
   * Drush command that translate.
   *
   * @param string $entity_type_id
   *    Entity Type ID.
   * @param string $bundle
   *    Bundle of entity type.
   *
   * @command nodejs_translate:multiple_translate entity_type_id bundle
   * @aliases nodejs-mt
   * @usage nodejs_translate:multiple_translate node article
   */
  public function message($entity_type_id, $bundle, $options = []) {
    if (empty($entity_type_id) || empty($bundle)) {
      $this->output()->writeln('nodejs_translate:multiple_translate command requires Entity Type ID and Bundle arguments');
    }

    $storage = $this->entityTypeManager->getStorage($entity_type_id);
    if (empty($storage)) {
      $this->output()->writeln('Couldn\'t load storage for entity type: ' . $entity_type_id);
      return;
    }

    $entities = $storage->loadByProperties(['type' => $bundle]);
    if (empty($entities)) {
      $this->output()->writeln('Missing entities to translate.');
      return;
    }
    foreach ($entities as $entity) {
      $this->translator->translateEntity($entity);
      $this->output()->writeln($entity_type_id . ' has been translated: ' . $entity->label());
    }
  }
}

==> nodejs_translate-1.0.2.tar.gz: nodejs_translate/src/Commands/MultipleTranslateCommand.php <==
<?php

namespace Drupal\nodejs_translate\Commands;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\nodejs_translate\NodejsTranslator;
use Drush\Commands\DrushCommands;

/**
 * A drush command file.
 *
 * @package Drupal\nodejs_translate\Commands
 */
class MultipleTranslateCommand extends DrushCommands {

  /**
   * Drupal\Core\Entity\EntityTypeManagerInterface definition.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Translator for text service.
   *
   * @var \Drupal\nodejs_translate\NodejsTranslator
   */
  protected $translator;

  /**
   * Constructs Node.js Multiple Translate command.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\nodejs_translate\NodejsTranslator $translator
   *   The text translator.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, NodejsTranslator $translator) {
    $this->entityTypeManager = $entity_type_manager;
    $this->translator = $translator;
  }

  /**
   * Drush command that translate.
   *
   * @param string $entity_type_id
   *   Entity Type ID.
   * @param string $bundle
   *   Bundle of entity type.
   *
   * @command nodejs_translate:multiple_translate entity_type_id bundle
   * @aliases nodejs-mt
   * @usage nodejs_translate:multiple_translate node article
   */
  public function message($entity_type_id, $bundle) {
    if (empty($entity_type_id) || empty($bundle)) {
      $this->output()->writeln('nodejs_translate:multiple_translate command requires Entity Type ID and Bundle arguments');
    }

    $storage = $this->entityTypeManager->getStorage($entity_type_id);
    if (empty($storage)) {
      $this->output()->writeln('Couldn\'t load storage for entity type: ' . $entity_type_id);
      return;
    }

    $entities = $storage->loadByProperties(['type' => $bundle]);
    if (empty($entities)) {
      $this->output()->writeln('Missing entities to translate.');
      return;
    }
    foreach ($entities as $entity) {
      $this->translator->translateEntity($entity);
      $this->output()->writeln($entity_type_id . ' has been translated: ' . $entity->label());
    }
  }

}
